#include "vriscv.h"
#include "memory/memory.h"
#include "bootloader/bootloader.h"
#include "cpu/rv32cpu.h"
#include "gdbstub/gdbstub.h"

char* CURRENT_NAME;

int main(int argc, char** argv)
{
    CURRENT_NAME = argc ? argv[0] : NAME;
    parse_options(argc, argv);

    // Initialize the memory
    mem_init();

    // Bootload the file passed as argument
    uint32_t entry_point = bootload(file_path);

    // Initialize the CPU
    cpu_init();
    cpu0->pc = entry_point;

    if(gdbstub)
    {
        gdbstub_start();
        gdbstub_wait_for_connection();
    }

    // CPU simulation : create cpu0 thread
    pthread_t cpu0_thread;
    pthread_create(&cpu0_thread, 0, (void*) cpu_loop, cpu0);

    // Wait for the simulation to end
    pthread_join(cpu0_thread, 0);
    
    return 0;
}
